@@ -42,3 +42,15 @@ class TestLoginLogout(TestCase):
         self.assertEquals(response.status_code, 200)
         # And empty.
         self.assertEquals(response.content, '')
+
+
+class TestUtility(TestCase):
+
+    def test_euro(self):
+        from lizard_ui.templatetags.utility import euro
+        self.assertEquals(u'&euro; 10,-', euro(10.0))
+        self.assertEquals(u'&euro; 10,-', euro(10))
+        self.assertEquals(u'&euro; 10.000,-', euro(10000))
+        self.assertEquals(u'&euro; 1.234.567,-', euro(1234567))
+        self.assertEquals(u'&euro; 1.234.567,-', euro(1234567.0))
+        euro(None)  # Should not crash
